package javax.swing.plaf.metal;

import java.awt.image.RGBImageFilter;
import java.awt.GradientPaint;
import java.awt.Color;
import sun.swing.CachedPainter;
import sun.swing.ImageIconUIResource;
import java.awt.image.FilteredImageSource;
import java.awt.Toolkit;
import javax.swing.Icon;
import java.awt.Image;
import javax.swing.JToolBar;
import javax.swing.JComponent;
import java.awt.Graphics2D;
import java.util.List;
import javax.swing.UIManager;
import java.awt.Component;
import java.awt.Rectangle;
import java.awt.Graphics;

class MetalUtils
{
    MetalUtils() {
    }
    
    static void drawFlush3DBorder(Graphics graphics, Rectangle rectangle) {
        drawFlush3DBorder(graphics, rectangle.x, rectangle.y, rectangle.width, rectangle.height);
    }
    
    static void drawFlush3DBorder(Graphics graphics, int n, int n2, int n3, int n4) {
        graphics.translate(n, n2);
        graphics.setColor(MetalLookAndFeel.getControlDarkShadow());
        graphics.drawRect(0, 0, n3 - 2, n4 - 2);
        graphics.setColor(MetalLookAndFeel.getControlHighlight());
        graphics.drawRect(1, 1, n3 - 2, n4 - 2);
        graphics.setColor(MetalLookAndFeel.getControl());
        graphics.drawLine(0, n4 - 1, 1, n4 - 2);
        graphics.drawLine(n3 - 1, 0, n3 - 2, 1);
        graphics.translate(-n, -n2);
    }
    
    static void drawPressed3DBorder(Graphics graphics, Rectangle rectangle) {
        drawPressed3DBorder(graphics, rectangle.x, rectangle.y, rectangle.width, rectangle.height);
    }
    
    static void drawDisabledBorder(Graphics graphics, int n, int n2, int n3, int n4) {
        graphics.translate(n, n2);
        graphics.setColor(MetalLookAndFeel.getControlShadow());
        graphics.drawRect(0, 0, n3 - 1, n4 - 1);
        graphics.translate(-n, -n2);
    }
    
    static void drawPressed3DBorder(Graphics graphics, int n, int n2, int n3, int n4) {
        graphics.translate(n, n2);
        drawFlush3DBorder(graphics, 0, 0, n3, n4);
        graphics.setColor(MetalLookAndFeel.getControlShadow());
        graphics.drawLine(1, 1, 1, n4 - 2);
        graphics.drawLine(1, 1, n3 - 2, 1);
        graphics.translate(-n, -n2);
    }
    
    static void drawDark3DBorder(Graphics graphics, Rectangle rectangle) {
        drawDark3DBorder(graphics, rectangle.x, rectangle.y, rectangle.width, rectangle.height);
    }
    
    static void drawDark3DBorder(Graphics graphics, int n, int n2, int n3, int n4) {
        graphics.translate(n, n2);
        drawFlush3DBorder(graphics, 0, 0, n3, n4);
        graphics.setColor(MetalLookAndFeel.getControl());
        graphics.drawLine(1, 1, 1, n4 - 2);
        graphics.drawLine(1, 1, n3 - 2, 1);
        graphics.setColor(MetalLookAndFeel.getControlShadow());
        graphics.drawLine(1, n4 - 2, 1, n4 - 2);
        graphics.drawLine(n3 - 2, 1, n3 - 2, 1);
        graphics.translate(-n, -n2);
    }
    
    static void drawButtonBorder(Graphics graphics, int n, int n2, int n3, int n4, boolean b) {
        if (b) {
            drawActiveButtonBorder(graphics, n, n2, n3, n4);
        }
        else {
            drawFlush3DBorder(graphics, n, n2, n3, n4);
        }
    }
    
    static void drawActiveButtonBorder(Graphics graphics, int n, int n2, int n3, int n4) {
        drawFlush3DBorder(graphics, n, n2, n3, n4);
        graphics.setColor(MetalLookAndFeel.getPrimaryControl());
        graphics.drawLine(n + 1, n2 + 1, n + 1, n4 - 3);
        graphics.drawLine(n + 1, n2 + 1, n3 - 3, n + 1);
        graphics.setColor(MetalLookAndFeel.getPrimaryControlDarkShadow());
        graphics.drawLine(n + 2, n4 - 2, n3 - 2, n4 - 2);
        graphics.drawLine(n3 - 2, n2 + 2, n3 - 2, n4 - 2);
    }
    
    static void drawDefaultButtonBorder(Graphics graphics, int n, int n2, int n3, int n4, boolean b) {
        drawButtonBorder(graphics, n + 1, n2 + 1, n3 - 1, n4 - 1, b);
        graphics.translate(n, n2);
        graphics.setColor(MetalLookAndFeel.getControlDarkShadow());
        graphics.drawRect(0, 0, n3 - 3, n4 - 3);
        graphics.drawLine(n3 - 2, 0, n3 - 2, 0);
        graphics.drawLine(0, n4 - 2, 0, n4 - 2);
        graphics.translate(-n, -n2);
    }
    
    static void drawDefaultButtonPressedBorder(Graphics graphics, int n, int n2, int n3, int n4) {
        drawPressed3DBorder(graphics, n + 1, n2 + 1, n3 - 1, n4 - 1);
        graphics.translate(n, n2);
        graphics.setColor(MetalLookAndFeel.getControlDarkShadow());
        graphics.drawRect(0, 0, n3 - 3, n4 - 3);
        graphics.drawLine(n3 - 2, 0, n3 - 2, 0);
        graphics.drawLine(0, n4 - 2, 0, n4 - 2);
        graphics.setColor(MetalLookAndFeel.getControl());
        graphics.drawLine(n3 - 1, 0, n3 - 1, 0);
        graphics.drawLine(0, n4 - 1, 0, n4 - 1);
        graphics.translate(-n, -n2);
    }
    
    static boolean isLeftToRight(Component component) {
        return component.getComponentOrientation().isLeftToRight();
    }
    
    static int getInt(Object key, int n) {
        Object value = UIManager.get(key);
        if ((value instanceof Integer)) {
            return (int)value;
        }
        if ((value instanceof String)) {
            try {
                return Integer.parseInt((String)value);
            }
            catch (NumberFormatException ex) {}
        }
        return n;
    }
    
    static boolean drawGradient(Component component, Graphics graphics, String key, int n, int n2, int n3, int n4, boolean b) {
        List<Object> list = (List)UIManager.get(key);
        if (list == null || !(graphics instanceof Graphics2D)) {
            return false;
        }
        if (n3 <= 0 || n4 <= 0) {
            return true;
        }
        MetalUtils.GradientPainter.INSTANCE.paint(component, (Graphics2D)graphics, list, n, n2, n3, n4, b);
        return true;
    }
    
    static boolean isToolBarButton(JComponent component) {
        return component.getParent() instanceof JToolBar;
    }
    
    static Icon getOceanToolBarIcon(Image image) {
        return new ImageIconUIResource(Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(image.getSource(), new MetalUtils.OceanToolBarImageFilter())));
    }
    
    static Icon getOceanDisabledButtonIcon(Image image) {
        Object[] array = (Object[])(Object[])UIManager.get("Button.disabledGrayRange");
        int intValue = 180;
        int intValue2 = 215;
        if (array != null) {
            intValue = (int)array[0];
            intValue2 = (int)array[1];
        }
        return new ImageIconUIResource(Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(image.getSource(), new OceanDisabledButtonImageFilter(intValue, intValue2))));
    }
    
    private static class GradientPainter extends CachedPainter
    {
        public static final MetalUtils.GradientPainter INSTANCE;
        private static final int IMAGE_SIZE = 64;
        private int w;
        private int h;
        
        GradientPainter(int cacheCount) {
            super(cacheCount);
        }
        
        public void paint(Component c, Graphics2D g, List list, int x, int y, int w, int h, boolean b) {
            int w2;
            if (b) {
                w2 = 64;
            }
            else {
                w2 = w;
                h = 64;
            }
            synchronized (c.getTreeLock()) {
                this.w = w;
                super.paint(c, g, x, y, w2, this.h = h, new Object[] { list, Boolean.valueOf(b) });
            }
        }
        
        @Override
        protected void paintToImage(Component component, Image image, Graphics graphics, int n, int n2, Object[] array) {
            Graphics2D graphics2D = (Graphics2D)graphics;
            List<Object> list = (List)array[0];
            if ((boolean)array[1]) {
                this.drawVerticalGradient(graphics2D, ((Number)list.get(0)).floatValue(), ((Number)list.get(1)).floatValue(), (Color)list.get(2), (Color)list.get(3), (Color)list.get(4), n, n2);
            }
            else {
                this.drawHorizontalGradient(graphics2D, ((Number)list.get(0)).floatValue(), ((Number)list.get(1)).floatValue(), (Color)list.get(2), (Color)list.get(3), (Color)list.get(4), n, n2);
            }
        }
        
        @Override
        protected void paintImage(Component component, Graphics graphics, int n, int n2, int n3, int n4, Image image, Object[] array) {
            int booleanValue = (boolean)array[1];
            graphics.translate(n, n2);
            if (!(booleanValue == 0)) {
                for (int j = 0; j < this.w; j += 64) {
                    int min2 = Math.min(64, this.w - j);
                    graphics.drawImage(image, j, 0, j + min2, this.h, 0, 0, min2, this.h, null);
                }
            }
            else {
                for (int i = 0; i < this.h; i += 64) {
                    int min = Math.min(64, this.h - i);
                    graphics.drawImage(image, 0, i, this.w, i + min, 0, 0, this.w, min, null);
                }
            }
            graphics.translate(-n, -n2);
        }
        
        private void drawVerticalGradient(Graphics2D graphics2D, float n, float n2, Color color, Color color2, Color color3, int n3, int n4) {
            int n5 = (int)(n * (float)n4);
            int n6 = (int)(n2 * (float)n4);
            if (n5 > 0) {
                graphics2D.setPaint(this.getGradient(0.0f, 0.0f, color, 0.0f, (float)n5, color2));
                graphics2D.fillRect(0, 0, n3, n5);
            }
            if (n6 > 0) {
                graphics2D.setColor(color2);
                graphics2D.fillRect(0, n5, n3, n6);
            }
            if (n5 > 0) {
                graphics2D.setPaint(this.getGradient(0.0f, (float)n5 + (float)n6, color2, 0.0f, (float)n5 * 2.0f + (float)n6, color));
                graphics2D.fillRect(0, n5 + n6, n3, n5);
            }
            if (n4 - n5 * 2 - n6 > 0) {
                graphics2D.setPaint(this.getGradient(0.0f, (float)n5 * 2.0f + (float)n6, color, 0.0f, (float)n4, color3));
                graphics2D.fillRect(0, n5 * 2 + n6, n3, n4 - n5 * 2 - n6);
            }
        }
        
        private void drawHorizontalGradient(Graphics2D graphics2D, float n, float n2, Color color, Color color2, Color color3, int n3, int n4) {
            int n5 = (int)(n * (float)n3);
            int n6 = (int)(n2 * (float)n3);
            if (n5 > 0) {
                graphics2D.setPaint(this.getGradient(0.0f, 0.0f, color, (float)n5, 0.0f, color2));
                graphics2D.fillRect(0, 0, n5, n4);
            }
            if (n6 > 0) {
                graphics2D.setColor(color2);
                graphics2D.fillRect(n5, 0, n6, n4);
            }
            if (n5 > 0) {
                graphics2D.setPaint(this.getGradient((float)n5 + (float)n6, 0.0f, color2, (float)n5 * 2.0f + (float)n6, 0.0f, color));
                graphics2D.fillRect(n5 + n6, 0, n5, n4);
            }
            if (n3 - n5 * 2 - n6 > 0) {
                graphics2D.setPaint(this.getGradient((float)n5 * 2.0f + (float)n6, 0.0f, color, (float)n3, 0.0f, color3));
                graphics2D.fillRect(n5 * 2 + n6, 0, n3 - n5 * 2 - n6, n4);
            }
        }
        
        private GradientPaint getGradient(float x1, float y1, Color color1, float x2, float y2, Color color2) {
            return new GradientPaint(x1, y1, color1, x2, y2, color2, true);
        }
        
        static {
            INSTANCE = new MetalUtils.GradientPainter(8);
        }
    }
    
    private static class OceanDisabledButtonImageFilter extends RGBImageFilter
    {
        private float min;
        private float factor;
        
        OceanDisabledButtonImageFilter(int n, int n2) {
            this.canFilterIndexColorModel = true;
            this.min = (float)n;
            this.factor = (float)(n2 - n) / 255.0f;
        }
        
        @Override
        public int filterRGB(int n, int n2, int n3) {
            int min = Math.min(255, (int)((0.2125f * (float)(n3 >> 16 & 0xFF) + 0.7154f * (float)(n3 >> 8 & 0xFF) + 0.0721f * (float)(n3 & 0xFF) + 0.5f) * this.factor + this.min));
            return (n3 & 0xFF000000) | min << 16 | min << 8 | min << 0;
        }
    }
    
    private static class OceanToolBarImageFilter extends RGBImageFilter
    {
        OceanToolBarImageFilter() {
            this.canFilterIndexColorModel = true;
        }
        
        @Override
        public int filterRGB(int n, int n2, int n3) {
            int max = Math.max(Math.max(n3 >> 16 & 0xFF, n3 >> 8 & 0xFF), n3 & 0xFF);
            return (n3 & 0xFF000000) | max << 16 | max << 8 | max << 0;
        }
    }
}
